@@ -323,6 +323,7 @@ my %determiners = (
     'OneValueChartDataPoint' => { 'Type' => 'OneValue', },
     'OneValueSeries' => { 'DataPointType' => 'OneValue', },
     'Operation' => {  },
+    'OperationProgress' => {  },
     'OrderedMergeRequest' => {  },
     'OuterShadowEffect' => {  },
     'OutputFile' => {  },
@@ -391,6 +392,7 @@ my %determiners = (
     'SlideProperties' => {  },
     'SlideReplaceResult' => {  },
     'SlideShowProperties' => {  },
+    'SlideShowTransition' => {  },
     'Slides' => {  },
     'SmartArt' => { 'Type' => 'SmartArt', },
     'SmartArtNode' => {  },
